Enum fred::types::BackpressurePolicy

source ·
pub enum BackpressurePolicy {
    Sleep {
        disable_backpressure_scaling: bool,
        min_sleep_duration: Duration,
    },
    Drain,
}
Backpressure policies to apply when the max number of in-flight commands is reached on a connection.

Variants



Sleep

Sleep for some amount of time before sending the next command.

Fields

disable_backpressure_scaling: bool

Disable the backpressure scaling logic used to calculate the sleep duration when throttling commands.

If true the client will always wait a constant amount of time defined by min_sleep_duration_ms when throttling commands. Otherwise the sleep duration will scale based on the number of in-flight commands.

Default: false

min_sleep_duration: Duration

The minimum amount of time to wait when applying backpressure to a command.

If 0 then no backpressure will be applied, but backpressure errors will not be surfaced to callers unless disable_auto_backpressure is true.

Default: 10 ms



Drain

Wait for all in-flight commands to finish before sending the next command.

Implementations

source

impl BackpressurePolicy

source

pub fn default_sleep() -> Self

Create a new Sleep policy with the legacy default values.