pub enum Blocking {
Block,
Error,
Interrupt,
}Expand description
Describes how the client should respond when a command is sent while the client is in a blocked state from a blocking command.
Variants
Block
Wait to send the command until the blocked command finishes. (Default)
Error
Return an error to the caller.
Interrupt
Interrupt the blocked command by automatically sending CLIENT UNBLOCK for the blocked connection.