Enum fred::types::ClusterDiscoveryPolicy
source · pub enum ClusterDiscoveryPolicy {
ConfigEndpoint,
UseCache,
}Expand description
A policy that determines how clustered clients initially connect to and discover other cluster nodes.
Variants
ConfigEndpoint
Always use the endpoint(s) provided in the client’s ServerConfig.
This is generally recommended with managed services, Kubernetes, or other systems that provide client routing or cluster discovery interfaces.
Default.
UseCache
Try connecting to nodes specified in both the client’s ServerConfig and the most recently cached routing table.