Enum fred::types::ClusterHash
source · pub enum ClusterHash {
FirstKey,
FirstValue,
Random,
Offset(usize),
Custom(u16),
}Expand description
A cluster hashing policy.
Variants
FirstKey
Hash the first string or bytes value in the arguments. (Default)
FirstValue
Hash the first argument regardless of type.
Random
Use a random node in the cluster.
Offset(usize)
Hash the value with the provided offset in the arguments array.
Custom(u16)
Provide a custom hash slot value.
Implementations
sourceimpl ClusterHash
impl ClusterHash
sourcepub fn hash(&self, args: &[RedisValue]) -> Option<u16>
pub fn hash(&self, args: &[RedisValue]) -> Option<u16>
Hash the provided arguments.
sourcepub fn find_key<'a>(&self, args: &'a [RedisValue]) -> Option<&'a [u8]>
pub fn find_key<'a>(&self, args: &'a [RedisValue]) -> Option<&'a [u8]>
Find the key to hash with the provided arguments.