Enum fred::types::ClusterStateChange
source · pub enum ClusterStateChange {
Add(Server),
Remove(Server),
Rebalance,
}Expand description
An enum describing the possible ways in which a Redis cluster can change state.
See on_cluster_change for more information.
Variants
Add(Server)
A node was added to the cluster.
This implies that hash slots were also probably rebalanced.
Remove(Server)
A node was removed from the cluster.
This implies that hash slots were also probably rebalanced.
Rebalance
Hash slots were rebalanced across the cluster and/or local routing state was updated.