Enum fred::types::ReconnectError

source ·
pub enum ReconnectError {
    ClusterDown,
    Loading,
    MasterDown,
    ReadOnly,
    Misconf,
    Busy,
    NoReplicas,
    Custom(&'static str),
}
Available on crate feature custom-reconnect-errors only.
Special errors that can trigger reconnection logic, which can also retry the failing command if possible.

MOVED, ASK, and NOAUTH errors are handled separately by the client.

Variants



ClusterDown

The CLUSTERDOWN prefix.



Loading

The LOADING prefix.



MasterDown

The MASTERDOWN prefix.



ReadOnly

The READONLY prefix, which can happen if a primary node is switched to a replica without any connection interruption.



Misconf

The MISCONF prefix.



Busy

The BUSY prefix.



NoReplicas

The NOREPLICAS prefix.



Custom(&'static str)

A case-sensitive prefix on an error message.

See the source for examples.