Enum fred::types::ReconnectPolicy
source · pub enum ReconnectPolicy {
Constant {
attempts: u32,
max_attempts: u32,
delay: u32,
jitter: u32,
},
Linear {
attempts: u32,
max_attempts: u32,
max_delay: u32,
delay: u32,
jitter: u32,
},
Exponential {
attempts: u32,
max_attempts: u32,
min_delay: u32,
max_delay: u32,
mult: u32,
jitter: u32,
},
}Expand description
The type of reconnection policy to use. This will apply to every connection used by the client.
Use a max_attempts value of 0 to retry forever.
Variants
Constant
Wait a constant amount of time between reconnect attempts, in ms.
Linear
Backoff reconnection attempts linearly, adding delay each time.
Exponential
Backoff reconnection attempts exponentially, multiplying the last delay by mult each time.
Implementations
sourceimpl ReconnectPolicy
impl ReconnectPolicy
sourcepub fn new_constant(max_attempts: u32, delay: u32) -> ReconnectPolicy
pub fn new_constant(max_attempts: u32, delay: u32) -> ReconnectPolicy
Create a new reconnect policy with a constant backoff.
sourcepub fn new_linear(
max_attempts: u32,
max_delay: u32,
delay: u32,
) -> ReconnectPolicy
pub fn new_linear( max_attempts: u32, max_delay: u32, delay: u32, ) -> ReconnectPolicy
Create a new reconnect policy with a linear backoff.
sourcepub fn new_exponential(
max_attempts: u32,
min_delay: u32,
max_delay: u32,
mult: u32,
) -> ReconnectPolicy
pub fn new_exponential( max_attempts: u32, min_delay: u32, max_delay: u32, mult: u32, ) -> ReconnectPolicy
Create a new reconnect policy with an exponential backoff.
sourcepub fn set_jitter(&mut self, jitter_ms: u32)
pub fn set_jitter(&mut self, jitter_ms: u32)
Set the amount of jitter to add to each reconnect delay.
Default: 50 ms
sourcepub fn next_delay(&mut self) -> Option<u64>
pub fn next_delay(&mut self) -> Option<u64>
Calculate the next delay, incrementing attempts in the process.