Enum fred::types::TlsHostMapping

source ·
pub enum TlsHostMapping {
    None,
    DefaultHost,
    Custom(Arc<dyn HostMapping>),
}
Available on crate features enable-rustls or enable-native-tls or enable-rustls-ring only.
An optional enum used to describe how the client should modify or map IP addresses and hostnames in a clustered deployment.

This is only necessary to use with a clustered deployment. Centralized or sentinel deployments should use None.

More information can be found here and here.

Variants



None

Do not modify or replace hostnames or IP addresses in the CLUSTER SLOTS response.

Default



DefaultHost

Replace any IP addresses in the CLUSTER SLOTS response with the hostname of the node that returned the CLUSTER SLOTS response.

If the CLUSTER SLOTS response contains hostnames alongside IP addresses (via the metadata block) then those hostnames will be used instead. However, this is a relatively new Redis feature and it’s likely some configurations will not expose this information.



Custom(Arc<dyn HostMapping>)

Provide a custom mapping from IP address to hostname to be used in a manner similar to a reverse DNS lookup.