Struct fred::types::BackpressureConfig
source · pub struct BackpressureConfig {
pub disable_auto_backpressure: bool,
pub max_in_flight_commands: u64,
pub policy: BackpressurePolicy,
}Expand description
Configuration options for backpressure features in the client.
Fields
disable_auto_backpressure: boolWhether to disable the automatic backpressure features when pipelining is enabled.
If true then RedisErrorKind::Backpressure errors may be surfaced to callers. Callers can set this to true
and max_in_flight_commands to 0 to effectively disable the backpressure logic.
Default: false
max_in_flight_commands: u64The maximum number of in-flight commands (per connection) before backpressure will be applied.
Default: 10_000
policy: BackpressurePolicyThe backpressure policy to apply when the max number of in-flight commands is reached.
Default: Drain.