Struct fred::types::ClusterRouting

source ·
pub struct ClusterRouting { /* private fields */ }
The cached view of the cluster used by the client to route commands to the correct cluster nodes.

Implementations

source

impl ClusterRouting

source

pub fn new() -> Self

Create a new empty routing table.

source

pub fn from_cluster_slots<S: Into<Str>>( value: RedisValue, default_host: S, ) -> Result<Self, RedisError>

Create a new routing table from the result of the CLUSTER SLOTS command.

The default_host value refers to the server that provided the response.

source

pub fn unique_hash_slots(&self) -> Vec<u16>

Read a set of unique hash slots that each map to a different primary/main node in the cluster.

source

pub fn unique_primary_nodes(&self) -> Vec<Server>

Read the set of unique primary nodes in the cluster.

source

pub fn hash_key(key: &[u8]) -> u16

Calculate the cluster hash slot for the provided key.

source

pub fn get_server(&self, slot: u16) -> Option<&Server>

Find the primary server that owns the provided hash slot.

source

pub fn replicas(&self, primary: &Server) -> Vec<Server>

Available on crate feature replicas only.

Read the replicas associated with the provided primary node based on the cached CLUSTER SLOTS response.

source

pub fn len(&self) -> usize

Read the number of hash slot ranges in the cluster.

source

pub fn slots(&self) -> &[SlotRange]

Read the hash slot ranges in the cluster.

source

pub fn random_slot(&self) -> Option<&SlotRange>

Read a random primary node hash slot range from the cluster cache.

source

pub fn random_node(&self) -> Option<&Server>

Read a random primary node from the cluster cache.

source

pub fn pretty(&self) -> BTreeMap<Server, (Vec<(u16, u16)>, BTreeSet<Server>)>

Print the contents of the routing table as a human-readable map.