Struct fred::types::CustomCommand
source · pub struct CustomCommand {
pub cmd: Str,
pub cluster_hash: ClusterHash,
pub blocking: bool,
}Expand description
Configuration for custom redis commands, primarily used for interacting with third party modules or extensions.
Fields
cmd: StrThe command name, sent directly to the server.
cluster_hash: ClusterHashThe cluster hashing policy to use, if any.
Cluster clients will use the default policy if not provided.
blocking: boolWhether the command should block the connection while waiting on a response.
Implementations
sourceimpl CustomCommand
impl CustomCommand
sourcepub fn new<C, H>(cmd: C, cluster_hash: H, blocking: bool) -> Self
pub fn new<C, H>(cmd: C, cluster_hash: H, blocking: bool) -> Self
Create a new custom command.
See the custom command for more information.
sourcepub fn new_static<H>(cmd: &'static str, cluster_hash: H, blocking: bool) -> Selfwhere
H: Into<ClusterHash>,
pub fn new_static<H>(cmd: &'static str, cluster_hash: H, blocking: bool) -> Selfwhere
H: Into<ClusterHash>,
Create a new custom command specified by a &'static str.