Struct fred::types::GeoPosition
source · pub struct GeoPosition {
pub longitude: f64,
pub latitude: f64,
}Available on crate feature
i-geo only.Expand description
A struct describing the longitude and latitude coordinates of a GEO command.
Fields
longitude: f64latitude: f64Trait Implementations
sourceimpl Clone for GeoPosition
impl Clone for GeoPosition
sourcefn clone(&self) -> GeoPosition
fn clone(&self) -> GeoPosition
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for GeoPosition
impl Debug for GeoPosition
sourceimpl FromRedis for GeoPosition
impl FromRedis for GeoPosition
fn from_value(value: RedisValue) -> Result<Self, RedisError>
sourceimpl PartialEq for GeoPosition
impl PartialEq for GeoPosition
sourceimpl TryFrom<RedisValue> for GeoPosition
impl TryFrom<RedisValue> for GeoPosition
sourcetype Error = RedisError
type Error = RedisError
The type returned in the event of a conversion error.
impl Eq for GeoPosition