Struct fred::types::GeoRadiusInfo
source · pub struct GeoRadiusInfo {
pub member: RedisValue,
pub position: Option<GeoPosition>,
pub distance: Option<f64>,
pub hash: Option<i64>,
}Available on crate feature
i-geo only.Expand description
A typed struct representing the full output of the GEORADIUS (or similar) command.
Fields
member: RedisValueposition: Option<GeoPosition>distance: Option<f64>hash: Option<i64>Implementations
sourceimpl GeoRadiusInfo
impl GeoRadiusInfo
sourcepub fn from_redis_value(
value: RedisValue,
withcoord: bool,
withdist: bool,
withhash: bool,
) -> Result<Self, RedisError>
pub fn from_redis_value( value: RedisValue, withcoord: bool, withdist: bool, withhash: bool, ) -> Result<Self, RedisError>
Parse the value with context from the calling command.