Struct fred::types::MultipleKeys
source · pub struct MultipleKeys { /* private fields */ }Expand description
Convenience struct for commands that take 1 or more keys.
Note: this can also be used to represent an empty array of keys by passing None to any function that takes
Into<MultipleKeys>. This is mostly useful for EVAL and EVALSHA.
Implementations
sourceimpl MultipleKeys
impl MultipleKeys
pub fn new() -> MultipleKeys
pub fn inner(self) -> Vec<RedisKey>
pub fn into_values(self) -> Vec<RedisValue>
pub fn len(&self) -> usize