Struct fred::types::PerformanceConfig
source · pub struct PerformanceConfig {
pub auto_pipeline: bool,
pub backpressure: BackpressureConfig,
pub default_command_timeout: Duration,
pub max_feed_count: u64,
pub broadcast_channel_capacity: usize,
pub blocking_encode_threshold: usize,
}Expand description
Configuration options that can affect the performance of the client.
Fields
auto_pipeline: boolWhether the client should automatically pipeline commands across tasks when possible.
The Pipeline interface can be used to pipeline commands within one task, whereas this flag can automatically pipeline commands across tasks.
Default: true
backpressure: BackpressureConfigConfiguration options for backpressure features in the client.
default_command_timeout: DurationAn optional timeout to apply to all commands.
If 0 this will disable any timeout being applied to commands. Callers can also set timeouts on individual
commands via the with_options interface.
Default: 0
max_feed_count: u64The maximum number of frames that will be fed to a socket before flushing.
Note: in some circumstances the client with always flush the socket (QUIT, EXEC, etc).
Default: 200
broadcast_channel_capacity: usizeThe default capacity used when creating broadcast channels in the EventInterface.
Default: 32
blocking_encode_threshold: usizeblocking-encoding only.The minimum size, in bytes, of frames that should be encoded or decoded with a blocking task.
See block_in_place for more information.
Default: 50_000_000