Struct fred::types::RedisKey

source ·
pub struct RedisKey { /* private fields */ }
A key in Redis.

Implementations

source

impl RedisKey

source

pub const fn from_static(b: &'static [u8]) -> Self

Create a new RedisKey from static bytes without copying.

source

pub const fn from_static_str(b: &'static str) -> Self

Create a new RedisKey from a &'static str without copying.

source

pub fn as_str(&self) -> Option<&str>

Read the key as a str slice if it can be parsed as a UTF8 string.

source

pub fn as_bytes(&self) -> &[u8]

Read the key as a byte slice.

source

pub fn inner(&self) -> &Bytes

Read the inner Bytes struct.

source

pub fn as_str_lossy(&self) -> Cow<'_, str>

Read the key as a lossy UTF8 string with String::from_utf8_lossy.

source

pub fn into_string(self) -> Option<String>

Convert the key to a UTF8 string, if possible.

source

pub fn into_bytes(self) -> Bytes

Read the inner bytes making up the key.

source

pub fn as_bytes_str(&self) -> Option<Str>

Parse and return the key as a Str without copying the inner contents.

source

pub fn cluster_hash(&self) -> u16

Hash the key to find the associated cluster hash slot.

source

pub fn cluster_owner<C>(&self, client: &C) -> Option<Server>
where C: ClientLike,

Read the host:port of the cluster node that owns the key if the client is clustered and the cluster state is known.

source

pub fn take(&mut self) -> Bytes

Replace this key with an empty byte array, returning the bytes from the original key.

source

pub fn convert<K>(self) -> Result<K, RedisError>
where K: FromRedisKey,

Attempt to convert the key to any type that implements FromRedisKey.

See the RedisValue::convert documentation for more information.