Struct fred::types::ReplicaConfig
source · pub struct ReplicaConfig {
pub lazy_connections: bool,
pub filter: Option<Rc<dyn ReplicaFilter>>,
pub ignore_reconnection_errors: bool,
pub connection_error_count: u32,
pub primary_fallback: bool,
}Available on crate feature
replicas only.Expand description
Configuration options for replica node connections.
Fields
lazy_connections: boolWhether the client should lazily connect to replica nodes.
Default: true
filter: Option<Rc<dyn ReplicaFilter>>An optional interface for filtering available replica nodes.
Default: None
ignore_reconnection_errors: boolWhether the client should ignore errors from replicas that occur when the max reconnection count is reached.
Default: true
connection_error_count: u32The number of times a command can fail with a replica connection error before being sent to a primary node.
Default: 0 (unlimited)
primary_fallback: boolWhether the client should use the associated primary node if no replica exists that can serve a command.
Default: true