Struct fred::types::SentinelConfig
source · pub struct SentinelConfig {
pub host: String,
pub port: u16,
pub username: Option<String>,
pub password: Option<String>,
pub tls: Option<TlsConfig>,
pub tracing: TracingConfig,
}Available on crate feature
sentinel-client only.Expand description
Configuration options for sentinel clients.
Fields
host: StringThe hostname for the sentinel node.
Default: 127.0.0.1
port: u16The port on which the sentinel node is listening.
Default: 26379
username: Option<String>An optional ACL username for the client to use when authenticating. If ACL rules are not configured this should
be None.
Default: None
password: Option<String>An optional password for the client to use when authenticating.
Default: None
tls: Option<TlsConfig>Available on crate features
enable-native-tls or enable-rustls or enable-rustls-ring only.TLS configuration fields. If None the connection will not use TLS.
See the tls examples on Github for more information.
Default: None
tracing: TracingConfigAvailable on crate feature
partial-tracing only.Whether to enable tracing for this client.
Default: false