Struct fred::types::UnresponsiveConfig

source ·
pub struct UnresponsiveConfig {
    pub max_timeout: Option<Duration>,
    pub interval: Duration,
}
Configuration options used to detect potentially unresponsive connections.

Fields

max_timeout: Option<Duration>

If provided, the amount of time a frame can wait without a response before the associated connection is considered unresponsive.

If a connection is considered unresponsive it will be forcefully closed and the client will reconnect based on the ReconnectPolicy. This heuristic can be useful in environments where connections may close or change in subtle or unexpected ways.

Unlike the timeout and default_command_timeout interfaces, any in-flight commands waiting on a response when the connection is closed this way will be retried based on the associated ReconnectPolicy and Options.

Default: None

interval: Duration

The frequency at which the client checks for unresponsive connections.

This value should usually be less than half of max_timeout and always more than 1 ms.

Default: 2 sec