Struct fred::types::XPendingArgs
source · pub struct XPendingArgs {
pub idle: Option<u64>,
pub start: Option<XID>,
pub end: Option<XID>,
pub count: Option<u64>,
pub consumer: Option<Str>,
}Available on crate feature
i-streams only.Expand description
A struct representing the trailing optional arguments to XPENDING.
See the From implementations for various shorthand representations of these arguments. Callers should use ()
to represent no arguments.
Fields
idle: Option<u64>start: Option<XID>end: Option<XID>count: Option<u64>consumer: Option<Str>Trait Implementations
sourceimpl Clone for XPendingArgs
impl Clone for XPendingArgs
sourcefn clone(&self) -> XPendingArgs
fn clone(&self) -> XPendingArgs
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for XPendingArgs
impl Debug for XPendingArgs
sourceimpl From<()> for XPendingArgs
impl From<()> for XPendingArgs
sourceimpl<S, E> From<(S, E, u64)> for XPendingArgs
impl<S, E> From<(S, E, u64)> for XPendingArgs
sourceimpl<S, E, C> From<(S, E, u64, C)> for XPendingArgs
impl<S, E, C> From<(S, E, u64, C)> for XPendingArgs
sourceimpl PartialEq for XPendingArgs
impl PartialEq for XPendingArgs
impl Eq for XPendingArgs
impl StructuralPartialEq for XPendingArgs