Enum fred::types::BackpressurePolicy
source · pub enum BackpressurePolicy {
Sleep {
disable_backpressure_scaling: bool,
min_sleep_duration: Duration,
},
Drain,
}Expand description
Backpressure policies to apply when the max number of in-flight commands is reached on a connection.
Variants
Sleep
Sleep for some amount of time before sending the next command.
Fields

disable_backpressure_scaling: boolDisable the backpressure scaling logic used to calculate the sleep duration when throttling commands.
If true the client will always wait a constant amount of time defined by min_sleep_duration_ms when
throttling commands. Otherwise the sleep duration will scale based on the number of in-flight commands.
Default: false
Drain
Wait for all in-flight commands to finish before sending the next command.
Implementations
sourceimpl BackpressurePolicy
impl BackpressurePolicy
sourcepub fn default_sleep() -> Self
pub fn default_sleep() -> Self
Create a new Sleep policy with the legacy default values.