Struct fred::types::ClusterRouting
source · pub struct ClusterRouting { /* private fields */ }Expand description
The cached view of the cluster used by the client to route commands to the correct cluster nodes.
Implementations
sourceimpl ClusterRouting
impl ClusterRouting
sourcepub fn from_cluster_slots<S: Into<Str>>(
value: RedisValue,
default_host: S,
) -> Result<Self, RedisError>
pub fn from_cluster_slots<S: Into<Str>>( value: RedisValue, default_host: S, ) -> Result<Self, RedisError>
Create a new routing table from the result of the CLUSTER SLOTS command.
The default_host value refers to the server that provided the response.
sourcepub fn unique_hash_slots(&self) -> Vec<u16>
pub fn unique_hash_slots(&self) -> Vec<u16>
Read a set of unique hash slots that each map to a different primary/main node in the cluster.
sourcepub fn unique_primary_nodes(&self) -> Vec<Server>
pub fn unique_primary_nodes(&self) -> Vec<Server>
Read the set of unique primary nodes in the cluster.
sourcepub fn get_server(&self, slot: u16) -> Option<&Server>
pub fn get_server(&self, slot: u16) -> Option<&Server>
Find the primary server that owns the provided hash slot.
sourcepub fn replicas(&self, primary: &Server) -> Vec<Server>
Available on crate feature replicas only.
pub fn replicas(&self, primary: &Server) -> Vec<Server>
replicas only.Read the replicas associated with the provided primary node based on the cached CLUSTER SLOTS response.
sourcepub fn random_slot(&self) -> Option<&SlotRange>
pub fn random_slot(&self) -> Option<&SlotRange>
Read a random primary node hash slot range from the cluster cache.
sourcepub fn random_node(&self) -> Option<&Server>
pub fn random_node(&self) -> Option<&Server>
Read a random primary node from the cluster cache.