pub struct RedisKey { /* private fields */ }Expand description
A key in Redis.
Implementations
sourceimpl RedisKey
impl RedisKey
sourcepub const fn from_static(b: &'static [u8]) -> Self
pub const fn from_static(b: &'static [u8]) -> Self
Create a new RedisKey from static bytes without copying.
sourcepub const fn from_static_str(b: &'static str) -> Self
pub const fn from_static_str(b: &'static str) -> Self
Create a new RedisKey from a &'static str without copying.
sourcepub fn as_str(&self) -> Option<&str>
pub fn as_str(&self) -> Option<&str>
Read the key as a str slice if it can be parsed as a UTF8 string.
sourcepub fn as_str_lossy(&self) -> Cow<'_, str>
pub fn as_str_lossy(&self) -> Cow<'_, str>
Read the key as a lossy UTF8 string with String::from_utf8_lossy.
sourcepub fn into_string(self) -> Option<String>
pub fn into_string(self) -> Option<String>
Convert the key to a UTF8 string, if possible.
sourcepub fn into_bytes(self) -> Bytes
pub fn into_bytes(self) -> Bytes
Read the inner bytes making up the key.
sourcepub fn as_bytes_str(&self) -> Option<Str>
pub fn as_bytes_str(&self) -> Option<Str>
Parse and return the key as a Str without copying the inner contents.
sourcepub fn cluster_hash(&self) -> u16
pub fn cluster_hash(&self) -> u16
Hash the key to find the associated cluster hash slot.
sourcepub fn cluster_owner<C>(&self, client: &C) -> Option<Server>where
C: ClientLike,
pub fn cluster_owner<C>(&self, client: &C) -> Option<Server>where
C: ClientLike,
Read the host:port of the cluster node that owns the key if the client is clustered and the cluster state is
known.
sourcepub fn take(&mut self) -> Bytes
pub fn take(&mut self) -> Bytes
Replace this key with an empty byte array, returning the bytes from the original key.
sourcepub fn convert<K>(self) -> Result<K, RedisError>where
K: FromRedisKey,
pub fn convert<K>(self) -> Result<K, RedisError>where
K: FromRedisKey,
Attempt to convert the key to any type that implements FromRedisKey.
See the RedisValue::convert documentation for more information.