Type Alias fred::types::ConnectHandle
source · pub type ConnectHandle = JoinHandle<Result<(), RedisError>>;Expand description
The result from any of the connect functions showing the error that closed the connection, if any.
Aliased Type
struct ConnectHandle { /* private fields */ }